pub enum ForgeSubcommand {
Show 33 variants
Test(TestArgs),
Fuzz(FuzzArgs),
Script(ScriptArgs),
Coverage(CoverageArgs),
Bind(BindArgs),
Build {
locked: bool,
args: BuildArgs,
},
Clone(CloneArgs),
Update(UpdateArgs),
Install(InstallArgs),
Remove(RemoveArgs),
Remappings(RemappingArgs),
VerifyContract(VerifyArgs),
VerifyCheck(VerifyCheckArgs),
VerifyBytecode(VerifyBytecodeArgs),
Create(CreateArgs),
Init(InitArgs),
Completions {
shell: Shell,
},
Clean {
root: Option<PathBuf>,
},
Cache(CacheArgs),
Snapshot(GasSnapshotArgs),
Config(ConfigArgs),
Flatten(FlattenArgs),
Fmt(FmtArgs),
Lint(LintArgs),
Inspect(InspectArgs),
Tree(TreeArgs),
Geiger(GeigerArgs),
Doc(DocArgs),
Selectors {
command: SelectorsSubcommands,
},
Compiler(CompilerArgs),
Soldeer(SoldeerArgs),
Eip712(Eip712Args),
BindJson(BindJsonArgs),
}Variants
Test(TestArgs)
Run the project’s tests
Examples:
- forge test
- forge test –match-test test_Increment -vvvv (show traces for a matching test)
- forge test –match-contract CounterTest –fuzz-runs 1000
Fuzz(FuzzArgs)
Run and manage Forge fuzzing corpora.
Script(ScriptArgs)
Run a smart contract as a script, building transactions that can be sent onchain
Examples:
- forge script script/Counter.s.sol (simulate the script locally)
- forge script script/Counter.s.sol –rpc-url $RPC_URL –broadcast –account dev
- forge script script/Counter.s.sol –rpc-url $RPC_URL –resume
Coverage(CoverageArgs)
Generate coverage reports
Examples:
- forge coverage
- forge coverage –report lcov –report-file lcov.info
- forge coverage –match-contract CounterTest
Bind(BindArgs)
Generate Rust bindings for smart contracts.
Build
Build the project’s smart contracts
Examples:
- forge build
- forge build –sizes (print a contract size report)
- forge build –watch (rebuild on file changes)
Clone(CloneArgs)
Clone a contract from Etherscan
Examples:
- forge clone $WETH weth –etherscan-api-key $KEY (clone WETH into ./weth)
- forge clone –chain sepolia –etherscan-api-key $KEY $ADDRESS my-contract
Update(UpdateArgs)
Update one or multiple dependencies.
If no arguments are provided, then all dependencies are updated.
Install(InstallArgs)
Install one or multiple dependencies
If no arguments are provided, then existing dependencies will be installed.
Examples:
- forge install (install all dependencies of the project)
- forge install openzeppelin/openzeppelin-contracts
- forge install openzeppelin/openzeppelin-contracts@v5.0.2 (pin a version)
Remove(RemoveArgs)
Remove one or multiple dependencies.
Remappings(RemappingArgs)
Get the automatically inferred remappings for the project.
VerifyContract(VerifyArgs)
Verify smart contracts on Etherscan and Sourcify
Examples:
- forge verify-contract –chain sepolia $ADDRESS src/Counter.sol:Counter –watch
- forge verify-contract $ADDRESS src/Counter.sol:Counter –verifier sourcify
VerifyCheck(VerifyCheckArgs)
Check verification status on the selected verifier.
VerifyBytecode(VerifyBytecodeArgs)
Verify the deployed bytecode against its source on Etherscan.
Create(CreateArgs)
Deploy a smart contract
Examples:
- forge create Counter –rpc-url $RPC_URL –account dev –broadcast
- forge create Token –private-key $PK –broadcast –constructor-args Token TKN
Init(InitArgs)
Create a new Forge project.
Completions
Generate shell completions script.
Fields
shell: ShellClean
Remove the build artifacts and cache directories.
Fields
Cache(CacheArgs)
Manage the Foundry cache.
Snapshot(GasSnapshotArgs)
Create a gas snapshot of each test’s gas usage
Examples:
- forge snapshot
- forge snapshot –diff (compare against the existing .gas-snapshot file)
- forge snapshot –check (fail if gas usage does not match .gas-snapshot)
Config(ConfigArgs)
Display the current config.
Flatten(FlattenArgs)
Flatten a source file and all of its imports into one file.
Fmt(FmtArgs)
Format Solidity source files
Examples:
- forge fmt
- forge fmt –check (report formatting issues without writing changes)
- forge fmt src/Counter.sol
Lint(LintArgs)
Lint Solidity source files
Inspect(InspectArgs)
Get specialized information about a smart contract
Examples:
- forge inspect Counter abi
- forge inspect Counter bytecode
- forge inspect src/Counter.sol:Counter storageLayout
Tree(TreeArgs)
Display a tree visualization of the project’s dependency graph.
Geiger(GeigerArgs)
DEPRECATED: Detects usage of unsafe cheat codes in a project and its dependencies.
This is an alias for forge lint --only-lint unsafe-cheatcode.
Doc(DocArgs)
Generate documentation for the project.
Selectors
Function selector utilities.
Fields
command: SelectorsSubcommandsCompiler(CompilerArgs)
Compiler utilities.
Soldeer(SoldeerArgs)
Soldeer dependency manager.
Eip712(Eip712Args)
Generate EIP-712 struct encodings for structs from a given file.
BindJson(BindJsonArgs)
Generate bindings for serialization/deserialization of project structs via JSON cheatcodes.